@@ -6,8 +6,7 @@
 import string
 
 from docx2python.main import docx2python
-
-from .conftest import RESOURCES
+from tests.conftest import RESOURCES
 
 
 class TestAsciiPrintable:
